==> atlassian_connect_host-0.5.0.tar.gz: test/host_service/host_service_registration_test.dart <==
library ac_dart.host_service.registration.test;

import 'package:atlassian_connect_host/src/host_service/host_service.dart';
import 'package:atlassian_connect_host/host_model.dart';
import 'package:atlassian_connect_host/host_event_model.dart';
import 'package:test/test.dart';
import 'package:mockito/mockito.dart';
import 'package:atlassian_connect_host/host_registration_persistence.dart';
import 'dart:io';

class _MockAcHostRegistrationRepository extends Mock
    implements AcHostRegistrationRepository {
  noSuchMethod(i) => super.noSuchMethod(i);
}

// HostClientFactory is a typedef

abstract class HostClientFactoryClass {
  AcHostHttpClient call(
      AcHostRegistration hostRegistration, AddonHost addonHost);
}

class _MockHostClientFactory extends Mock implements HostClientFactoryClass {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockAcHostHttpClient extends Mock implements AcHostHttpClient {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientRequest extends Mock implements HttpClientRequest {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpHeaders extends Mock implements HttpHeaders {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientResponse extends Mock implements HttpClientResponse {
  noSuchMethod(i) => super.noSuchMethod(i);
}

main() {
  const String addonKey = 'my-addon';
  final Uri addonBaseUri = Uri.parse('http://localhost:9999/foo');
  const String hostKey = 'jira:2345';
  const String publicKey = '93475ljsdrt93kwd';

  final AddonHost addonHost = new AddonHost(addonKey, addonBaseUri);

  final _hostRegistration = (new AcHostRegistration.build(
      sharedSecret: "1234",
      hostDetails: (new AcHostDetails.build(
          key: "$hostKey",
          baseUrl: Uri.parse('http://localhost:8080/blah'),
          productType: ProductType.jira,
          publicKey: "$publicKey"))));

  final _installationEvent = new InstallationEvent(_hostRegistration);

  _MockAcHostRegistrationRepository _registrationRepository;
  _MockHostClientFactory _hostClientFactory;
  _MockAcHostHttpClient _hostHttpClient;
  _MockHttpClientRequest _httpClientRequest;
  _MockHttpHeaders _httpHeaders;
  _MockHttpClientResponse _httpClientResponse;

  const String _goodRespXml = '''
    <resp>
      <key>$hostKey</key>
      <publicKey>$publicKey</publicKey>
    </resp>
    ''';

  group('[Registration]', () {
    AcHostService hostService;

    setUp(() {
      _registrationRepository = new _MockAcHostRegistrationRepository();
      _hostClientFactory = new _MockHostClientFactory();
      hostService = new AcHostService(_registrationRepository, addonHost,
          (hostRego, addonHost) =>
              _hostClientFactory.call(hostRego, addonHost));
      _hostHttpClient = new _MockAcHostHttpClient();
      _httpClientRequest = new _MockHttpClientRequest();
      _httpHeaders = new _MockHttpHeaders();
      _httpClientResponse = new _MockHttpClientResponse();

      when(_hostClientFactory.call(any, any)).thenReturn(_hostHttpClient);
      when(_hostHttpClient.get(any,
          signRequest: any,
          queryParams: any,
          subject: any)).thenReturn(new Future.value(_httpClientRequest));
      when(_httpClientRequest.headers).thenReturn(_httpHeaders);
      when(_httpClientRequest.close())
          .thenReturn(new Future.value(_httpClientResponse));
      when(_httpClientResponse.transform(any)).thenReturn(_httpClientResponse);
      when(_httpClientResponse.fold(any, any))
          .thenReturn(new Future.value(_goodRespXml));
      when(_registrationRepository.create(any)).thenReturn(_hostRegistration);

      // ouch ended up being a truck load of mocking!!!
    });

    //TODO: lots more test cases.

    test('persists registration', () {
      when(_registrationRepository.findRegistrationByHostKey(any))
          .thenReturn(new Future.value(const None()));

      final Future<AcHostRegistration> regoFuture =
          hostService.registerHost(_installationEvent);
      regoFuture.then((_) {
        verify(_registrationRepository.create(_hostRegistration)).called(1);
      });
      expect(regoFuture, completes);
    });

    test('rejects registration if exsiting for key', () {
      when(_registrationRepository.findRegistrationByHostKey(any))
          .thenReturn(new Future.value(new Some(_hostRegistration)));

      final Future<AcHostRegistration> regoFuture =
          hostService.registerHost(_installationEvent);
      expect(regoFuture, throwsArgumentError);
    });
  });

  // TODO: unittest installAddonToHost
}

==> atlassian_connect_host-0.5.4.tar.gz: test/host_service/host_service_registration_test.dart <==
library ac_dart.host_service.registration.test;

import 'package:atlassian_connect_host/src/host_service/host_service.dart';
import 'package:atlassian_connect_host/host_model.dart';
import 'package:atlassian_connect_host/host_event_model.dart';
import 'package:test/test.dart';
import 'package:mockito/mockito.dart';
import 'package:atlassian_connect_host/host_registration_persistence.dart';
import 'dart:io';

class _MockAcHostRegistrationRepository extends Mock
    implements AcHostRegistrationRepository {
  noSuchMethod(i) => super.noSuchMethod(i);
}

// HostClientFactory is a typedef

abstract class HostClientFactoryClass {
  AcHostHttpClient call(
      AcHostRegistration hostRegistration, AddonHost addonHost);
}

class _MockHostClientFactory extends Mock implements HostClientFactoryClass {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockAcHostHttpClient extends Mock implements AcHostHttpClient {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientRequest extends Mock implements HttpClientRequest {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpHeaders extends Mock implements HttpHeaders {
  noSuchMethod(i) => super.noSuchMethod(i);
}

class _MockHttpClientResponse extends Mock implements HttpClientResponse {
  noSuchMethod(i) => super.noSuchMethod(i);
}

main() {
  const String addonKey = 'my-addon';
  final Uri addonBaseUri = Uri.parse('http://localhost:9999/foo');
  const String hostKey = 'jira:2345';
  const String publicKey = '93475ljsdrt93kwd';

  final AddonHost addonHost = new AddonHost(addonKey, addonBaseUri);

  final _hostRegistration = (new AcHostRegistration.build(
      sharedSecret: "1234",
      hostDetails: (new AcHostDetails.build(
          key: "$hostKey",
          baseUrl: Uri.parse('http://localhost:8080/blah'),
          productType: ProductType.jira,
          publicKey: "$publicKey"))));

  final _installationEvent = new InstallationEvent(_hostRegistration);

  _MockAcHostRegistrationRepository _registrationRepository;
  _MockHostClientFactory _hostClientFactory;
  _MockAcHostHttpClient _hostHttpClient;
  _MockHttpClientRequest _httpClientRequest;
  _MockHttpHeaders _httpHeaders;
  _MockHttpClientResponse _httpClientResponse;

  const String _goodRespXml = '''
    <resp>
      <key>$hostKey</key>
      <publicKey>$publicKey</publicKey>
    </resp>
    ''';

  group('[Registration]', () {
    AcHostService hostService;

    setUp(() {
      _registrationRepository = new _MockAcHostRegistrationRepository();
      _hostClientFactory = new _MockHostClientFactory();
      hostService = new AcHostService(
          _registrationRepository,
          addonHost,
          (hostRego, addonHost) =>
              _hostClientFactory.call(hostRego, addonHost));
      _hostHttpClient = new _MockAcHostHttpClient();
      _httpClientRequest = new _MockHttpClientRequest();
      _httpHeaders = new _MockHttpHeaders();
      _httpClientResponse = new _MockHttpClientResponse();

      when(_hostClientFactory.call(any, any)).thenReturn(_hostHttpClient);
      when(_hostHttpClient.get(any,
          signRequest: any,
          queryParams: any,
          subject: any)).thenReturn(new Future.value(_httpClientRequest));
      when(_httpClientRequest.headers).thenReturn(_httpHeaders);
      when(_httpClientRequest.close())
          .thenReturn(new Future.value(_httpClientResponse));
      when(_httpClientResponse.transform(any)).thenReturn(_httpClientResponse);
      when(_httpClientResponse.fold(any, any))
          .thenReturn(new Future.value(_goodRespXml));
      when(_registrationRepository.create(any)).thenReturn(_hostRegistration);

      // ouch ended up being a truck load of mocking!!!
    });

    //TODO: lots more test cases.

    test('persists registration', () {
      when(_registrationRepository.findRegistrationByHostKey(any))
          .thenReturn(new Future.value(const None()));

      final Future<AcHostRegistration> regoFuture =
          hostService.registerHost(_installationEvent);
      regoFuture.then((_) {
        verify(_registrationRepository.create(_hostRegistration)).called(1);
      });
      expect(regoFuture, completes);
    });

    test('rejects registration if exsiting for key', () {
      when(_registrationRepository.findRegistrationByHostKey(any))
          .thenReturn(new Future.value(new Some(_hostRegistration)));

      final Future<AcHostRegistration> regoFuture =
          hostService.registerHost(_installationEvent);
      expect(regoFuture, throwsArgumentError);
    });
  });

  // TODO: unittest installAddonToHost
}
